Watford Tournament Watford, England May 26th 2002 12 players Tony Smith Deck Name: You die, we win. Created by: Tony 'literary Thug' Smith, with a bit of creative inspiration from Jon Cooper. Didn't have too many problems on the day and the combination of bone crunching combat and 2nd tradition seemed to handle most things. A little slow getting the first point in the final, which nearly scuppered my plans. The first version of this had 4 Don Cruez. I later decided that using a smaller crypt and another Protean master was probably the way to go. I may even drop the Dons to 2 and add a second Beast. I usually went for either Theo or Volker first, on the basis that the Don was just too big. Although, to be fair, his maneuver did save me a couple of times against the Wookie's assamites. Not much in the way of subtlety, but hey, burning vampires is fun. Remember kids, don't do drugs. Tony Literary Thug Crypt (13 cards, min=16, max=37, avg=6.46) ------------------------------------------ 3x Don Cruez, The Idealist 10 CEL POT PRE ani dom pro justicar Brujah:1 2x Theo Bell 7 POT cel dom pre Brujah:2 2x Volker, The Puppet Prince 5 CEL pot prince Brujah:2 1x Beast, The Leatherface of Detroit 7 OBF POT ani cel Nosferatu antitribu:2 1x Anvil 6 CEL POT dom pre tha primogen Brujah:1 1x Jimmy Dunn 4 CEL POT for Pander:2 1x Victor Tolliver 4 CEL pot Brujah antitribu:2 1x Dre, Leader of the Cold Dawn 3 cel pot Brujah:1 1x Tony 6 AUS DEM dom obf Malkavian:3 Library (90 cards) Master (12) 4x Blood Doll 1x Depravity 1x Minion Tap 5x Protean 1x Rack, The Action (8) 4x Ambush 4x Bum's Rush Reaction (6) 5x Second Tradition: Domain 1x Wake with Evening's Freshness Combat (64) 5x Blur 3x Bone Spur 2x Claws of the Dead 3x Decapitate 3x Disarm 4x Flash 6x Flesh of Marble 7x Immortal Grapple 2x Psyche! 3x Pursuit 2x Side Strike 2x Sideslip 5x Taste of Vitae 9x Torn Signpost 7x Undead Strength 1x Wolf Claws